==> rpc2_1.28+debian.orig.tar.gz: rpc2-1.28+debian/rp2gen/rp2gen_parser.h <==
/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IDENTIFIER = 258,
     NUMBER = 259,
     STRING = 260,
     SUBSYSTEM = 261,
     TIMEOUT = 262,
     DEFINE = 263,
     NEW_CONNECTION = 264,
     TYPEDEF = 265,
     RPC2_STRUCT = 266,
     RPC2_ENUM = 267,
     CLIENT = 268,
     SERVER = 269,
     PREFIX = 270,
     IN = 271,
     OUT = 272
   };
#endif
#define IDENTIFIER 258
#define NUMBER 259
#define STRING 260
#define SUBSYSTEM 261
#define TIMEOUT 262
#define DEFINE 263
#define NEW_CONNECTION 264
#define TYPEDEF 265
#define RPC2_STRUCT 266
#define RPC2_ENUM 267
#define CLIENT 268
#define SERVER 269
#define PREFIX 270
#define IN 271
#define OUT 272




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 187 "rp2gen_parser.y"
typedef union YYSTYPE {
    rp2_bool	u_bool;
    MODE	u_mode;
    char	*u_string;
    char	**u_string_array;
    RPC2_TYPE	*u_rpc2_type;
    ENTRY	*u_entry;
    ENUM	*u_enum;
    VAR		*u_var;
    VAR		**u_var_array;
    VAR		***u_var_array_array;
    int         u_int;
} YYSTYPE;
/* Line 1285 of yacc.c.  */
#line 85 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

==> rpc2_2.0+debian.orig.tar.gz: rpc2-2.0+debian/rp2gen/rp2gen_parser.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IDENTIFIER = 258,
     NUMBER = 259,
     STRING = 260,
     SUBSYSTEM = 261,
     TIMEOUT = 262,
     DEFINE = 263,
     NEW_CONNECTION = 264,
     TYPEDEF = 265,
     RPC2_STRUCT = 266,
     RPC2_ENUM = 267,
     CLIENT = 268,
     SERVER = 269,
     PREFIX = 270,
     IN = 271,
     OUT = 272
   };
#endif
/* Tokens.  */
#define IDENTIFIER 258
#define NUMBER 259
#define STRING 260
#define SUBSYSTEM 261
#define TIMEOUT 262
#define DEFINE 263
#define NEW_CONNECTION 264
#define TYPEDEF 265
#define RPC2_STRUCT 266
#define RPC2_ENUM 267
#define CLIENT 268
#define SERVER 269
#define PREFIX 270
#define IN 271
#define OUT 272




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 187 "rp2gen_parser.y"
typedef union YYSTYPE {
    rp2_bool	u_bool;
    MODE	u_mode;
    char	*u_string;
    char	**u_string_array;
    RPC2_TYPE	*u_rpc2_type;
    ENTRY	*u_entry;
    ENUM	*u_enum;
    VAR		*u_var;
    VAR		**u_var_array;
    VAR		***u_var_array_array;
    int         u_int;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 86 "y.tab.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
